Crate glh

Crate glh 

Structs

ProgramBuilder

Functions

compile_shader
create_buffer
Creates an OpenGL buffer and fills it with the provided data.
create_program
create_texture_2d_grayscale
create_texture_2d_grayscale_alpha
create_texture_2d_rgb
create_texture_2d_rgba
enable_interleaved_vertex_array_attributes
Enables a series of interleaved vertex array attributes all of the same type and in the same buffer.
get_error
Checks for OpenGL errors and returns an error message if any are found.
get_texture_size
standard_debug_callback