Structs
Functions
- compile_
shader - create_
buffer - Creates an OpenGL buffer and fills it with the provided data.
- create_
program - create_
texture_ 2d_ grayscale - create_
texture_ 2d_ grayscale_ alpha - create_
texture_ 2d_ rgb - create_
texture_ 2d_ rgba - enable_
interleaved_ vertex_ array_ attributes - Enables a series of interleaved vertex array attributes all of the same type and in the same buffer.
- get_
error - Checks for OpenGL errors and returns an error message if any are found.
- get_
texture_ size - standard_
debug_ callback